@@ -67,7 +67,8 @@ def move_right(app):
 
 def change_view(app):
     app.screen.clear()
-    app.title_bar(text="Q = quit, B = Next page", align="bottom", color=121)
+    app.widget("title_bar", text="Q = quit, B = Next page",
+               align="bottom", color=121)
     if selector.current_view == "line_drawing":
         selector.current_view = "block_elements"
         selector.cv_index = 0
@@ -109,7 +110,7 @@ def table_drawing(app, selection, table):
             row += 2
             index_of_everything[1] += 1
     python_content = "Name: {}".format(selector.current_selection)
-    extra_space = " " * (app.cols - (56 + len(python_content)))
+    extra_space = " " * (app.cols - len(python_content))
     app.print(panel="layout.0",
               content=python_content + extra_space, x=2, y=24)
     app.print(panel="layout.0",
@@ -125,7 +126,8 @@ def table_drawing(app, selection, table):
 def dashport(stdscr):
     app = Dashport(stdscr)
     height = app.rows - 2
-    app.title_bar(text="Q = quit, B = Next page", align="bottom", color=121)
+    app.widget("title_bar", text="Q = quit, B = Next page",
+               align="bottom", color=121)
     app.layout("single_panel", scroll=True, height=height)
     app.add_control("q", quit)
     app.add_control("KEY_UP", move_up)
